/*
 *  Copyright 2008 Mikhail Kryshen
 *
 *  This file is part of Charamega.
 *
 *  Charamega is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Charamega is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Charamega.  If not, see <http://www.gnu.org/licenses/>.
 */

package kryshen.charamega;

import javafx.ui.*;
import javafx.ui.canvas.*;
import javafx.ui.filter.*;
import javafx.animation.*;

/**
 * Field view.
 */
class Field extends CompositeNode {
    attribute width:Integer;
    attribute height:Integer;    
    attribute model:FieldModel = FieldModel {};

    attribute closeTimer = Timeline {
        keyFrames:          
        KeyFrame {
            time: 500ms
            action: model.checkPair
        }
    };
    
    attribute status = bind model.status on replace o = n { 
        // Stop the pair close timer when game stops.
        if (n <> FieldModel.STATUS_RUNNING) {
            closeTimer.stop();
        }
    }

    public function composeNode():Node {
        return Group {
            content: 
            bind for (c in model.cards)
                Card {
                    field: this
                    model: bind c
                }
        }
    }
    
    function checkOpened():Void {
        if (model.opened2 <> null) {
            closeTimer.start();   
        }        
    }
    
    function interruptWait():Void {        
        closeTimer.stop();
        if (model.opened2 <> null) {
            model.checkPair();
        }
    }
}
